@@ -1,29 +1,37 @@
 import glob
 import logging
-import pathlib
-from pathlib import Path
 from typing import List, Dict
 
-from brain_brew.representation.json.json_file import JsonFile
+from brain_brew.representation.generic.source_file import SourceFile
 from brain_brew.representation.generic.media_file import MediaFile
+from brain_brew.representation.json.json_file import JsonFile
+from brain_brew.representation.json.wrappers_for_crowd_anki import CrowdAnkiJsonWrapper
 from brain_brew.utils import filename_from_full_path, find_all_files_in_directory
 
 
-class CrowdAnkiExport(JsonFile):
+class CrowdAnkiExport(SourceFile):
     folder_location: str
+    json_file_location: str
+    # import_config: CrowdAnkiImportConfig  # TODO: Make this
+
     contains_media: bool
     known_media: Dict[str, MediaFile]
     media_loc: str
 
-    def __init__(self, folder_location, read_now=True, data_override=None):
+    def __init__(self, folder_location):
         self.folder_location = folder_location
         if self.folder_location[-1] != "/":
             self.folder_location = self.folder_location + "/"
 
-        json_file_location = self.find_json_file_in_folder()
+        if not self.is_dir(self.folder_location):
+            raise FileNotFoundError(f"Missing CrowdAnkiExport '{self.folder_location}'")
+
+        self.json_file_location = self.find_json_file_in_folder()
         self.find_all_media()
 
-        super().__init__(json_file_location, read_now=read_now, data_override=data_override)
+    @classmethod
+    def from_file_loc(cls, file_loc) -> 'CrowdAnkiExport':
+        return cls(file_loc)
 
     def find_json_file_in_folder(self):
         files = glob.glob(self.folder_location + "*.json")
@@ -39,8 +47,8 @@ class CrowdAnkiExport(JsonFile):
 
     def find_all_media(self):
         self.known_media = {}
-        self.media_loc = self.folder_location + "media/"  # TODO: Make media folder if not exists
-        self.contains_media = Path(self.media_loc).is_dir()
+        self.media_loc = self.folder_location + "media/"
+        self.contains_media = self.is_dir(self.media_loc)
 
         if not self.contains_media:
             return
@@ -53,7 +61,10 @@ class CrowdAnkiExport(JsonFile):
 
         logging.info(f"CrowdAnkiExport found {len(self.known_media)} media files in folder")
 
-    def write_file(self, data_override=None):
-        super().write_file(data_override)
-        for filename, media_file in self.known_media.items():
-            media_file.copy_source_to_target()
+    def write_to_files(self, json_data):  # import_config_data
+        JsonFile.write_file(self.json_file_location, json_data)
+        # for filename, media_file in self.known_media.items():
+        #     media_file.copy_source_to_target()
+
+    def read_json_file(self) -> CrowdAnkiJsonWrapper:
+        return CrowdAnkiJsonWrapper(JsonFile.read_file(self.json_file_location))
